Introduction — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# Introduction

`psychopy_ext` is a framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology.

Unlike `PsychoPy`, `PyMVPA` or `matplotlib` that are very flexible and support multiple options to suit everyone’s needs, the underlying philosophy of `psychopy_ext` is to act as the glue at a higher level of operation by choosing reasonable defaults for these packages and providing patterns for common tasks with a minimal user intervention. Set up your stimuli, trial structure and go! Everything else is already done for you.

## Getting started

- Demo
- Quick start
  - Structure
  - What to do
- Basic architecture
- Why use psychopy_ext?
- Frequently asked questions
  - Installation with pip is failing
  - Where do I find demo files?
  - How do I run demos?
  - Why can’t I run fMRI demo?
  - How / where do I write my own scripts?
  - In the source code, why are some variables in camelBack, and others just lower_case?

## License

Copyright 2010-2014 Jonas Kubilius (http://klab.lt)

Laboratories of Biological and Experimental Psychology, KU Leuven (Belgium)

GNU General Public License v3 or later

Included external packages and functions (covered by a compatible license): combinations, combinations_with_replacement, OrderedDict, HMAX, GaborJet

## Acknowledgements

I would like to thank Jonathan Peirce, Jeremy Gray and all PsychoPy developers for the well maintained code from which I learned a lot about development, Scott Torborg and The Hitchhiker’s guide to packaging for guiding me in packaging, and ZetCode for examples on dealing with wxPython.

Jonas Kubilius is a Research Assistant of the Research Foundation – Flanders (FWO).